@@ -61,7 +61,7 @@ _VCNL4010_AMBIENTPARAMETER = const(0x84)
 _VCNL4010_AMBIENTDATA = const(0x85)
 _VCNL4010_PROXIMITYDATA = const(0x87)
 _VCNL4010_INTCONTROL = const(0x89)
-_VCNL4010_PROXINITYADJUST = const(0x8A)
+_VCNL4010_PROXIMITYADJUST = const(0x8A)
 _VCNL4010_INTSTAT = const(0x8E)
 _VCNL4010_MODTIMING = const(0x8F)
 _VCNL4010_MEASUREAMBIENT = const(0x10)
